@@ -2,7 +2,7 @@
 knitr::opts_chunk$set(collapse = T, comment = "#>")
 
 ## ---- lib, eval=TRUE-----------------------------------------------------
-library("pollen")
+library(pollen)
 
 ## ---- dat, eval=TRUE-----------------------------------------------------
 data("pollen_count")
@@ -17,17 +17,19 @@ df2 <- subset(pollen_count, site == "Atlantis")
 pollen_season(value = df2$alder, date = df2$date, method = "95")
 
 ## ---- purrr, eval=TRUE---------------------------------------------------
-library("purrr")
+library(purrr)
 pollen_count %>%
   split(., .$site) %>%
-  map_df(~pollen_season(value = .$hazel, date = .$date, method = "95"), .id = "site")
+  map_dfr(~pollen_season(value = .$hazel, date = .$date, method = "95"), .id = "site")
 
 ## ------------------------------------------------------------------------
 df <- subset(pollen_count, site == "Oz")
 
+## ------------------------------------------------------------------------
 ps_methods <- c("90", "95", "98", "Mesa", "Jager", "Lejoly")
-names(ps_methods) <- c("90", "95", "98", "Mesa", "Jager", "Lejoly")
-df_seasons <- ps_methods %>% map_df(~pollen_season(method = ., value = df$birch, date = df$date), .id = "method")
+names(ps_methods) <- ps_methods
+df_seasons <- ps_methods %>%
+  map_dfr(~pollen_season(method = ., value = df$birch, date = df$date), .id = "method")
 head(df_seasons)
 
 ## ------------------------------------------------------------------------
@@ -39,5 +41,5 @@ identical(df, new_df)
 library("purrr")
 new_pollen_count <- pollen_count %>%
   split(., .$site) %>%
-  map_df(~outliers_replacer(value = .$hazel, date = .$date, threshold = 4))
+  map_dfr(~outliers_replacer(value = .$hazel, date = .$date, threshold = 4))
 
